@@ -3,6 +3,7 @@ import re
 import sqlite3
 import subprocess
 import time
+import traceback
 from time import sleep
 
 from performance.config import WORK_DIR
@@ -52,6 +53,7 @@ class AndroidApp:
         self.success = True
         self.ptk_crash_dir = None
         self.ptk_anr_dir = None
+        self.crashes = 0
         self.conn = sqlite3.connect(DB_NAME)
         create_table_if_need(History(), self.conn)
 
@@ -137,13 +139,30 @@ class AndroidApp:
         tip("(%s) start dump..." % self.series)
         excel = excelx()
         try:
+            last_datas = None
             datas = self.get_memory()
             excel.create_memory_sheet(self.get_output_file(".xlsx"), datas)
 
+            crashed = False
             while self.run:
                 datas = self.get_memory()
+
+                # crash count
                 excel.add_data(datas)
                 cur = datas['Total']
+                if cur == 0:
+                    crashed = True
+                else:
+                    if crashed:
+                        if last_datas is None:
+                            continue
+                        last = last_datas['Total']
+                        if last - cur > 1000:
+                            self.crashes += 1
+                            print("crash count +1  -> %d" % self.crashes)
+                            self.logcat_e_count(self.crashes)
+                    crashed = False
+                    last_datas = datas
                 if cur > self.max:
                     self.max = cur
                 if self.avg == 0:
@@ -153,6 +172,8 @@ class AndroidApp:
                 sleep(DUMP_INTERVAL)
         except Exception as e:
             self.success = False
+            msg = traceback.format_exc()
+            print("dump_memory: %s " % msg)
             raise e
         finally:
             tip("(%s) dump stopped!!!" % self.series)
@@ -192,6 +213,7 @@ class AndroidApp:
         report.plt_history = history_temp
         report.lint_file = self.__get_lint_file()
         report.checkstyle_file = self.__get_checkstyle_file()
+        report.crash_count = self.crashes
 
         mail.send_mail(report)
 
@@ -217,6 +239,9 @@ class AndroidApp:
         # subprocess.check_output(' '.join(args), shell=True)
         self.adb_shell("logcat -c")
 
+    def logcat_e_count(self, count: int):
+        self.adb_shell("logcat -v threadtime -t 2000 > %s " % self.get_output_file(".e.%d.logcat" % count, parent='ptk_app_crash'))
+
     def logcat(self):
         # args = ['adb']
         # if self.series is not None:
@@ -260,9 +285,12 @@ class AndroidApp:
                 tip("kill process %s(%s) failed!" % (process, pid), e)
                 pass
 
-    def get_output_file(self, suffix):
-        assert isinstance(suffix, str)
-        return self.output + os.path.sep + self.file_prefix + suffix
+    def get_output_file(self, suffix: str, parent=None):
+        file_dir = self.output
+        if parent is not None and parent.__len__() > 0:
+            file_dir = file_dir + os.path.sep + parent
+            os.makedirs(file_dir, exist_ok=True)
+        return file_dir + os.path.sep + self.file_prefix + suffix
 
     def get_anr_files(self):
         if self.ptk_anr_dir is None:
