@@ -13,5 +13,5 @@ def get_errors_warnings(file: str):
         words = tar_line.strip().split(">")[1].strip().split("<")[0]
         return words
     except Exception as e:
-        print(e)
+        print("get_errors_warnings: ", e)
     return 'Lint Report: no data'
