@@ -7,7 +7,7 @@ import performance
 
 from performance.android import AndroidApp
 
-from performance import VERSION, android, properties, config
+from performance import VERSION, android, properties, config, log
 from performance import android_device
 from performance.android_device import Device
 from performance.config import WORK_DIR
@@ -19,6 +19,7 @@ def usage():
     print("usage: ptk [-d device] [-o output] [-t duration] [-p property_file] [-s] [-v] [-h] <app_package_name>")
     print()
     print("-h 打印此帮助")
+    print("-c 清除历史logcat文件")
     print("-d 设备号，可以通过adb devices命令拿到")
     print("-v 打印ptk版本号")
     print("-o 数据，日志的输出目录")
@@ -31,21 +32,46 @@ def version():
     return '.'.join(str(v) for v in VERSION)
 
 
+def clear_logcat(output: str, file_type=".logcat"):
+    if not os.path.exists(output):
+        log.tip("output dir not exists: " + output)
+        return
+    for date in os.listdir(output):  # 日期: 2019-01-02
+        date_dir = os.path.join(output, date)
+        if not os.path.isdir(date_dir):
+            continue
+        for pkg in os.listdir(date_dir):
+            pkg_dir = os.path.join(date_dir, pkg)
+            if not os.path.isdir(pkg_dir):
+                continue
+            for series in os.listdir(pkg_dir):  # series: ac9ea8d97d94
+                series_dir = os.path.join(pkg_dir, series)
+                if not os.path.isdir(series_dir):
+                    continue
+                for f in os.listdir(series_dir):  # files: xxx.logcat, xxx.xlsx, xxx.monkey
+                    f_path = os.path.join(series_dir, f)
+                    if f.endswith(file_type):
+                        os.remove(f_path)
+
+
 def main():
     #
     devices = None
     output = WORK_DIR
     series = None
     stop = False
+    clear = False
 
     hours = 10.0
     try:
-        opts, args = getopt(sys.argv[1:], "d:o:t:p:shv")
+        opts, args = getopt(sys.argv[1:], "d:o:t:p:cshv")
         for op, value in opts:
             if op == '-o':
                 output = value
             elif op == '-d':
                 series = value
+            elif op == '-c':
+                clear = True
             elif op == '-h':
                 usage()
                 exit(0)
@@ -61,6 +87,10 @@ def main():
                     tip("配置文件不存在: %s " % value)
                     exit(1)
                 config.ptk_properties = properties.parse(value)
+        if clear:
+            clear_logcat(output)
+            exit(0)
+
         if len(args) < 1:
             usage()
             exit(1)
@@ -134,6 +164,6 @@ class DeviceThread(threading.Thread):
         try:
             self.device.start()
         except Exception as e:
-            raise e
+            log.tip(e)
         finally:
             android.stop(self.device.app)
